@@ -359,7 +359,7 @@ chat_text_view_maybe_trim_buffer (EmpathyChatTextView *view)
 	EmpathyChatTextViewPriv *priv;
 	GtkTextIter         top, bottom;
 	gint                line;
-	gint                remove;
+	gint                remove_;
 	GtkTextTagTable    *table;
 	GtkTextTag         *tag;
 
@@ -371,11 +371,11 @@ chat_text_view_maybe_trim_buffer (EmpathyChatTextView *view)
 		return;
 	}
 
-	remove = line - MAX_LINES;
+	remove_ = line - MAX_LINES;
 	gtk_text_buffer_get_start_iter (priv->buffer, &top);
 
 	bottom = top;
-	if (!gtk_text_iter_forward_lines (&bottom, remove)) {
+	if (!gtk_text_iter_forward_lines (&bottom, remove_)) {
 		return;
 	}
 
@@ -506,7 +506,7 @@ chat_text_view_drag_motion (GtkWidget      *widget,
 			    GdkDragContext *context,
 			    gint            x,
 			    gint            y,
-			    guint           time)
+			    guint           time_)
 {
 	/* Don't handle drag motion, since we don't want the view to scroll as
 	 * the result of dragging something across it. */
@@ -1159,14 +1159,61 @@ static void
 chat_text_view_copy_clipboard (EmpathyChatView *view)
 {
 	GtkTextBuffer *buffer;
+	GtkTextIter start, iter, end;
 	GtkClipboard  *clipboard;
+	GdkPixbuf *pixbuf;
+	gunichar c;
+	GtkTextChildAnchor *anchor = NULL;
+	GString *str;
+	GList *list;
+	gboolean ignore_newlines = FALSE;
 
 	g_return_if_fail (EMPATHY_IS_CHAT_TEXT_VIEW (view));
 
 	buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
 	clipboard = gtk_clipboard_get (GDK_SELECTION_CLIPBOARD);
 
-	gtk_text_buffer_copy_clipboard (buffer, clipboard);
+	if (!gtk_text_buffer_get_selection_bounds (buffer, &start, &end))
+		return;
+
+	str = g_string_new ("");
+
+	for (iter = start; !gtk_text_iter_equal (&iter, &end); gtk_text_iter_forward_char (&iter)) {
+		c = gtk_text_iter_get_char (&iter);
+		/* 0xFFFC is the 'object replacement' unicode character,
+		 * it indicates the presence of a pixbuf or a widget. */
+		if (c == 0xFFFC) {
+			ignore_newlines = FALSE;
+			if ((pixbuf = gtk_text_iter_get_pixbuf (&iter))) {
+				gchar *text;
+				text = g_object_get_data (G_OBJECT(pixbuf),
+							  "smiley_str");
+				if (text)
+					str = g_string_append (str, text);
+			} else if ((anchor = gtk_text_iter_get_child_anchor (&iter))) {
+				gchar *text;
+				list = gtk_text_child_anchor_get_widgets (anchor);
+				if (list) {
+					text = g_object_get_data (G_OBJECT(list->data),
+								  "str_obj");
+					if (text)
+						str = g_string_append (str, text);
+				}
+				g_list_free (list);
+			}
+		} else if (c == '\n') {
+			if (!ignore_newlines) {
+				ignore_newlines = TRUE;
+				str = g_string_append_unichar (str, c);
+			}
+		} else {
+			ignore_newlines = FALSE;
+			str = g_string_append_unichar (str, c);
+		}
+	}
+
+	gtk_clipboard_set_text (clipboard, str->str, str->len);
+	g_string_free (str, TRUE);
 }
 
 static void
@@ -1295,7 +1342,7 @@ empathy_chat_text_view_append_body (EmpathyChatTextView *view,
 	g_match_info_free (match_info);
 	g_regex_unref (uri_regex);
 
-	if (last < strlen (body)) {
+	if (last < (gint) strlen (body)) {
 		gtk_text_buffer_get_end_iter (priv->buffer, &iter);
 		chat_text_view_insert_text_with_emoticons (view,
 							   &iter,
