@@ -31,6 +31,9 @@
 #include "empathy-connection-managers.h"
 #include "empathy-utils.h"
 
+#define DEBUG_FLAG EMPATHY_DEBUG_ACCOUNT
+#include <libempathy/empathy-debug.h>
+
 #define GET_PRIV(obj) EMPATHY_GET_PRIV (obj, EmpathyAccountSettings)
 
 G_DEFINE_TYPE(EmpathyAccountSettings, empathy_account_settings, G_TYPE_OBJECT)
@@ -55,7 +58,6 @@ struct _EmpathyAccountSettingsPriv
   gulong account_manager_ready_id;
 
   TpConnectionManager *manager;
-  const TpConnectionManagerProtocol *tp_protocol;
 
   EmpathyAccount *account;
   gchar *cm_name;
@@ -318,7 +320,7 @@ empathy_account_settings_free_unset_parameters (
     EmpathyAccountSettings *settings)
 {
   EmpathyAccountSettingsPriv *priv = GET_PRIV (settings);
-  int i;
+  guint i;
 
   for (i = 0 ; i < priv->unset_parameters->len; i++)
     g_free (g_array_index (priv->unset_parameters, gchar *, i));
@@ -353,6 +355,7 @@ static void
 empathy_account_settings_check_readyness (EmpathyAccountSettings *self)
 {
   EmpathyAccountSettingsPriv *priv = GET_PRIV (self);
+  const TpConnectionManagerProtocol *tp_protocol;
 
   if (priv->ready)
     return;
@@ -380,10 +383,10 @@ empathy_account_settings_check_readyness (EmpathyAccountSettings *self)
         g_strdup (empathy_account_get_icon_name (priv->account));
     }
 
-  priv->tp_protocol = tp_connection_manager_get_protocol (priv->manager,
+  tp_protocol = tp_connection_manager_get_protocol (priv->manager,
     priv->protocol);
 
-  if (priv->tp_protocol == NULL)
+  if (tp_protocol == NULL)
     {
       priv->manager = NULL;
       return;
@@ -396,7 +399,7 @@ empathy_account_settings_check_readyness (EmpathyAccountSettings *self)
 
       priv->required_params = g_array_new (TRUE, FALSE, sizeof (gchar *));
 
-      for (cur = priv->tp_protocol->params; cur->name != NULL; cur++)
+      for (cur = tp_protocol->params; cur->name != NULL; cur++)
         {
           if (tp_connection_manager_param_is_required (cur))
             {
@@ -446,10 +449,21 @@ TpConnectionManagerParam *
 empathy_account_settings_get_tp_params (EmpathyAccountSettings *settings)
 {
   EmpathyAccountSettingsPriv *priv = GET_PRIV (settings);
+  const TpConnectionManagerProtocol *tp_protocol;
 
-  g_return_val_if_fail (priv->tp_protocol != NULL, NULL);
+  g_return_val_if_fail (priv->manager != NULL, NULL);
+  g_return_val_if_fail (priv->protocol != NULL, NULL);
 
-  return priv->tp_protocol->params;
+  tp_protocol = tp_connection_manager_get_protocol (priv->manager,
+     priv->protocol);
+  if (tp_protocol == NULL)
+    {
+      DEBUG ("Can't retrieve TpConnectionManagerProtocol for protocol '%s'",
+          priv->protocol);
+      return NULL;
+    }
+
+  return tp_protocol->params;
 }
 
 gboolean
@@ -506,7 +520,7 @@ empathy_account_settings_is_unset (EmpathyAccountSettings *settings,
 {
   EmpathyAccountSettingsPriv *priv = GET_PRIV (settings);
   GArray *a;
-  int i;
+  guint i;
 
   a = priv->unset_parameters;
 
@@ -543,7 +557,7 @@ account_settings_remove_from_unset (EmpathyAccountSettings *settings,
     const gchar *param)
 {
   EmpathyAccountSettingsPriv *priv = GET_PRIV (settings);
-  int idx;
+  guint idx;
   gchar *val;
 
   for (idx = 0; idx < priv->unset_parameters->len; idx++)
@@ -677,13 +691,15 @@ empathy_account_settings_get_int32 (EmpathyAccountSettings *settings,
         ret = g_value_get_int (v);
         break;
       case G_TYPE_UINT:
-        ret = CLAMP (G_MININT32, g_value_get_uint (v), G_MAXINT32);
+        ret = CLAMP (g_value_get_uint (v), (guint) G_MININT32,
+            G_MAXINT32);
         break;
       case G_TYPE_INT64:
-        ret = CLAMP (G_MININT32, g_value_get_int64 (v), G_MAXINT32);
+        ret = CLAMP (g_value_get_int64 (v), G_MININT32, G_MAXINT32);
         break;
       case G_TYPE_UINT64:
-        ret = CLAMP (G_MININT32, g_value_get_uint64 (v), G_MAXINT32);
+        ret = CLAMP (g_value_get_uint64 (v), (guint64) G_MININT32,
+            G_MAXINT32);
         break;
       default:
         ret = 0;
@@ -719,7 +735,7 @@ empathy_account_settings_get_int64 (EmpathyAccountSettings *settings,
         ret = g_value_get_int64 (v);
         break;
       case G_TYPE_UINT64:
-        ret = CLAMP (G_MININT64, g_value_get_uint64 (v), G_MAXINT64);
+        ret = CLAMP (g_value_get_uint64 (v), (guint64) G_MININT64, G_MAXINT64);
         break;
       default:
         ret = 0;
@@ -752,10 +768,10 @@ empathy_account_settings_get_uint32 (EmpathyAccountSettings *settings,
         ret = g_value_get_uint (v);
         break;
       case G_TYPE_INT64:
-        ret = CLAMP (0, g_value_get_int64 (v), G_MAXUINT32);
+        ret = CLAMP (g_value_get_int64 (v), 0, G_MAXUINT32);
         break;
       case G_TYPE_UINT64:
-        ret = CLAMP (0, g_value_get_uint64 (v), G_MAXUINT32);
+        ret = MIN (g_value_get_uint64 (v), G_MAXUINT32);
         break;
       default:
         ret = 0;
@@ -792,7 +808,7 @@ empathy_account_settings_get_uint64 (EmpathyAccountSettings *settings,
         ret = MAX (0, g_value_get_int64 (v));
         break;
       case G_TYPE_UINT64:
-        ret = CLAMP (0, g_value_get_uint64 (v), G_MAXUINT64);
+        ret = g_value_get_uint64 (v);
         break;
       default:
         ret = 0;
@@ -1224,7 +1240,7 @@ gboolean
 empathy_account_settings_is_valid (EmpathyAccountSettings *settings)
 {
   EmpathyAccountSettingsPriv *priv;
-  int idx;
+  guint idx;
   gchar *current;
   gboolean missed = FALSE;
 
