@@ -30,6 +30,8 @@
 #include <libxml/parser.h>
 #include <libxml/tree.h>
 
+#include <telepathy-glib/interfaces.h>
+
 #include "empathy-tp-chat.h"
 #include "empathy-chatroom-manager.h"
 #include "empathy-account-manager.h"
@@ -50,8 +52,10 @@ typedef struct
   GList *chatrooms;
   gchar *file;
   EmpathyAccountManager *account_manager;
+  gulong account_manager_ready_handler_id;
   /* source id of the autosave timer */
   gint save_timer_id;
+  gboolean ready;
 } EmpathyChatroomManagerPriv;
 
 enum {
@@ -66,6 +70,7 @@ static guint signals[LAST_SIGNAL];
 enum
 {
   PROP_FILE = 1,
+  PROP_READY,
   LAST_PROPERTY
 };
 
@@ -85,8 +90,8 @@ chatroom_manager_file_save (EmpathyChatroomManager *manager)
 
 	priv = GET_PRIV (manager);
 
-	doc = xmlNewDoc ("1.0");
-	root = xmlNewNode (NULL, "chatrooms");
+	doc = xmlNewDoc ((const xmlChar *) "1.0");
+	root = xmlNewNode (NULL, (const xmlChar *) "chatrooms");
 	xmlDocSetRootElement (doc, root);
 
 	for (l = priv->chatrooms; l; l = l->next) {
@@ -103,12 +108,16 @@ chatroom_manager_file_save (EmpathyChatroomManager *manager)
 		account_id = empathy_account_get_unique_name (
 		  empathy_chatroom_get_account (chatroom));
 
-		node = xmlNewChild (root, NULL, "chatroom", NULL);
-		xmlNewTextChild (node, NULL, "name", empathy_chatroom_get_name (chatroom));
-		xmlNewTextChild (node, NULL, "room", empathy_chatroom_get_room (chatroom));
-		xmlNewTextChild (node, NULL, "account", account_id);
-		xmlNewTextChild (node, NULL, "auto_connect",
-			empathy_chatroom_get_auto_connect (chatroom) ? "yes" : "no");
+		node = xmlNewChild (root, NULL, (const xmlChar *) "chatroom", NULL);
+		xmlNewTextChild (node, NULL, (const xmlChar *) "name",
+			(const xmlChar *) empathy_chatroom_get_name (chatroom));
+		xmlNewTextChild (node, NULL, (const xmlChar *) "room",
+			(const xmlChar *) empathy_chatroom_get_name (chatroom));
+		xmlNewTextChild (node, NULL, (const xmlChar *) "account",
+			(const xmlChar *) account_id);
+		xmlNewTextChild (node, NULL, (const xmlChar *) "auto_connect",
+			empathy_chatroom_get_auto_connect (chatroom) ?
+			(const xmlChar *) "yes" : (const xmlChar *) "no");
 	}
 
 	/* Make sure the XML is indented properly */
@@ -221,7 +230,8 @@ chatroom_manager_parse_chatroom (EmpathyChatroomManager *manager,
 		xmlFree (str);
 	}
 
-	account = empathy_account_manager_lookup (priv->account_manager, account_id);
+	account = empathy_account_manager_get_account (priv->account_manager,
+		account_id);
 	if (!account) {
 		g_free (name);
 		g_free (room);
@@ -234,7 +244,6 @@ chatroom_manager_parse_chatroom (EmpathyChatroomManager *manager,
 	add_chatroom (manager, chatroom);
 	g_signal_emit (manager, signals[CHATROOM_ADDED], 0, chatroom);
 
-	g_object_unref (account);
 	g_free (name);
 	g_free (room);
 	g_free (account_id);
@@ -301,6 +310,9 @@ chatroom_manager_get_all (EmpathyChatroomManager *manager)
 		return FALSE;
 	}
 
+        priv->ready = TRUE;
+        g_object_notify (G_OBJECT (manager), "ready");
+
 	return TRUE;
 }
 
@@ -318,6 +330,9 @@ empathy_chatroom_manager_get_property (GObject *object,
       case PROP_FILE:
         g_value_set_string (value, priv->file);
         break;
+      case PROP_READY:
+        g_value_set_boolean (value, priv->ready);
+        break;
       default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
         break;
@@ -354,6 +369,12 @@ chatroom_manager_finalize (GObject *object)
 
   priv = GET_PRIV (object);
 
+  if (priv->account_manager_ready_handler_id > 0)
+    {
+      g_signal_handler_disconnect (priv->account_manager,
+          priv->account_manager_ready_handler_id);
+    }
+
   g_object_unref (priv->account_manager);
 
   if (priv->save_timer_id > 0)
@@ -380,6 +401,21 @@ chatroom_manager_finalize (GObject *object)
   (G_OBJECT_CLASS (empathy_chatroom_manager_parent_class)->finalize) (object);
 }
 
+static void
+account_manager_ready_cb (GObject *gobject,
+                          GParamSpec *pspec,
+                          gpointer user_data)
+{
+  EmpathyChatroomManager *self = EMPATHY_CHATROOM_MANAGER (user_data);
+  EmpathyChatroomManagerPriv *priv = GET_PRIV (self);
+
+  chatroom_manager_get_all (self);
+
+  g_signal_handler_disconnect (gobject,
+      priv->account_manager_ready_handler_id);
+  priv->account_manager_ready_handler_id = 0;
+}
+
 static GObject *
 empathy_chatroom_manager_constructor (GType type,
                                       guint n_props,
@@ -399,11 +435,22 @@ empathy_chatroom_manager_constructor (GType type,
   self = EMPATHY_CHATROOM_MANAGER (obj);
   priv = GET_PRIV (self);
 
+  priv->ready = FALSE;
+
   chatroom_manager_singleton = self;
   g_object_add_weak_pointer (obj, (gpointer) &chatroom_manager_singleton);
 
   priv->account_manager = empathy_account_manager_dup_singleton ();
 
+  priv->account_manager_ready_handler_id = 0;
+
+  if (empathy_account_manager_is_ready (priv->account_manager))
+    chatroom_manager_get_all (self);
+  else
+    priv->account_manager_ready_handler_id =  g_signal_connect (
+        G_OBJECT (priv->account_manager), "notify::ready",
+        G_CALLBACK (account_manager_ready_cb), self);
+
   if (priv->file == NULL)
     {
       /* Set the default file path */
@@ -417,7 +464,6 @@ empathy_chatroom_manager_constructor (GType type,
       g_free (dir);
     }
 
-  chatroom_manager_get_all (self);
   return obj;
 }
 
@@ -444,6 +490,14 @@ empathy_chatroom_manager_class_init (EmpathyChatroomManagerClass *klass)
       G_PARAM_STATIC_BLURB);
   g_object_class_install_property (object_class, PROP_FILE, param_spec);
 
+  param_spec = g_param_spec_boolean (
+      "ready",
+      "whether the manager is ready yet",
+      "whether the manager is ready yet",
+      FALSE,
+      G_PARAM_READABLE);
+  g_object_class_install_property (object_class, PROP_READY, param_spec);
+
   signals[CHATROOM_ADDED] = g_signal_new ("chatroom-added",
       G_TYPE_FROM_CLASS (klass),
       G_SIGNAL_RUN_LAST,
@@ -578,9 +632,8 @@ empathy_chatroom_manager_find (EmpathyChatroomManager *manager,
 		this_account = empathy_chatroom_get_account (chatroom);
 		this_room = empathy_chatroom_get_room (chatroom);
 
-		if (this_account && this_room &&
-		    empathy_account_equal (account, this_account) &&
-		    strcmp (this_room, room) == 0) {
+		if (this_account && this_room && account == this_account
+				&& strcmp (this_room, room) == 0) {
 			return chatroom;
 		}
 	}
@@ -609,8 +662,7 @@ empathy_chatroom_manager_get_chatrooms (EmpathyChatroomManager *manager,
 
 		chatroom = l->data;
 
-		if (empathy_account_equal (account,
-					  empathy_chatroom_get_account (chatroom))) {
+		if (account == empathy_chatroom_get_account (chatroom)) {
 			chatrooms = g_list_append (chatrooms, chatroom);
 		}
 	}
@@ -639,8 +691,7 @@ empathy_chatroom_manager_get_count (EmpathyChatroomManager *manager,
 
 		chatroom = l->data;
 
-		if (empathy_account_equal (account,
-					   empathy_chatroom_get_account (chatroom))) {
+		if (account == empathy_chatroom_get_account (chatroom)) {
 			count++;
 		}
 	}
@@ -705,8 +756,8 @@ chatroom_manager_observe_channel_cb (EmpathyDispatcher *dispatcher,
   chat = EMPATHY_TP_CHAT (
     empathy_dispatch_operation_get_channel_wrapper (operation));
   connection = empathy_tp_chat_get_connection (chat);
-  account = empathy_account_manager_get_account (priv->account_manager,
-      connection);
+  account = empathy_account_manager_get_account_for_connection (
+      priv->account_manager, connection);
 
   roomname = empathy_tp_chat_get_id (chat);
 
