@@ -27,14 +27,7 @@
 #include <string.h>
 #include <stdio.h>
 #include <stdlib.h>
-
-/* FIXME: g_mapped_file_free has been deprecated in GLib 2.22, but the
- * replacement symbol, g_mapped_file_unref is not available in older Glib
- * and we're not ready to bump our version requirement just for this. When
- * we're ready to bump our version requirement, just revert this patch. */
-#undef G_DISABLE_DEPRECATED
 #include <glib/gstdio.h>
-#define G_DISABLE_DEPRECATED
 
 #include <telepathy-glib/util.h>
 #include <telepathy-glib/defs.h>
@@ -487,7 +480,7 @@ log_store_empathy_get_messages_for_file (EmpathyLogStore *self,
     {
       EmpathyMessage *message;
       EmpathyContact *sender;
-      gchar *time;
+      gchar *time_;
       time_t t;
       gchar *sender_id;
       gchar *sender_name;
@@ -500,17 +493,18 @@ log_store_empathy_get_messages_for_file (EmpathyLogStore *self,
       guint cm_id;
       TpChannelTextMessageType msg_type = TP_CHANNEL_TEXT_MESSAGE_TYPE_NORMAL;
 
-      if (strcmp (node->name, "message") != 0)
+      if (strcmp ((const gchar *) node->name, "message") != 0)
         continue;
 
-      body = xmlNodeGetContent (node);
-      time = xmlGetProp (node, "time");
-      sender_id = xmlGetProp (node, "id");
-      sender_name = xmlGetProp (node, "name");
-      sender_avatar_token = xmlGetProp (node, "token");
-      is_user_str = xmlGetProp (node, "isuser");
-      msg_type_str = xmlGetProp (node, "type");
-      cm_id_str = xmlGetProp (node, "cm_id");
+      body = (gchar *) xmlNodeGetContent (node);
+      time_ = (gchar *) xmlGetProp (node, (const xmlChar *) "time");
+      sender_id = (gchar *) xmlGetProp (node, (const xmlChar *) "id");
+      sender_name = (gchar *) xmlGetProp (node, (const xmlChar *) "name");
+      sender_avatar_token = (gchar *) xmlGetProp (node,
+          (const xmlChar *) "token");
+      is_user_str = (gchar *) xmlGetProp (node, (const xmlChar *) "isuser");
+      msg_type_str = (gchar *) xmlGetProp (node, (const xmlChar *) "type");
+      cm_id_str = (gchar *) xmlGetProp (node, (const xmlChar *) "cm_id");
 
       if (is_user_str)
         is_user = strcmp (is_user_str, "true") == 0;
@@ -521,7 +515,7 @@ log_store_empathy_get_messages_for_file (EmpathyLogStore *self,
       if (cm_id_str)
         cm_id = atoi (cm_id_str);
 
-      t = empathy_time_parse (time);
+      t = empathy_time_parse (time_);
 
       sender = empathy_contact_new_for_log (account, sender_id, sender_name,
 					    is_user);
@@ -542,7 +536,7 @@ log_store_empathy_get_messages_for_file (EmpathyLogStore *self,
       messages = g_list_append (messages, message);
 
       g_object_unref (sender);
-      xmlFree (time);
+      xmlFree (time_);
       xmlFree (sender_id);
       xmlFree (sender_name);
       xmlFree (body);
@@ -638,7 +632,7 @@ log_store_empathy_search_new (EmpathyLogStore *self,
       contents = g_mapped_file_get_contents (file);
       contents_casefold = g_utf8_casefold (contents, length);
 
-      g_mapped_file_free (file);
+      g_mapped_file_unref (file);
 
       if (strstr (contents_casefold, text_casefold))
         {
