@@ -78,6 +78,7 @@ typedef struct {
   GtkWidget *treeview;
 
   GtkWidget *button_add;
+  GtkWidget *button_import;
 
   GtkWidget *frame_new_account;
   GtkWidget *combobox_protocol;
@@ -216,6 +217,9 @@ get_default_display_name (EmpathyAccountSettings *settings)
   login_id = empathy_account_settings_get_string (settings, "account");
   protocol = empathy_account_settings_get_protocol (settings);
 
+  if ((p = empathy_protocol_name_to_display_name (protocol)) != NULL)
+    protocol = p;
+
   if (login_id != NULL)
     {
       if (!tp_strdiff (protocol, "irc"))
@@ -235,14 +239,8 @@ get_default_display_name (EmpathyAccountSettings *settings)
         {
           default_display_name = g_strdup (login_id);
         }
-
-      return default_display_name;
     }
-
-  if ((p = empathy_protocol_name_to_display_name (protocol)) != NULL)
-    protocol = p;
-
-  if (protocol != NULL)
+  else if (protocol != NULL)
     {
       /* To translators: The parameter is the protocol name. The resulting
        * string will be something like: "Jabber Account" */
@@ -1476,6 +1474,18 @@ accounts_dialog_button_help_clicked_cb (GtkWidget *button,
   empathy_url_show (button, "ghelp:empathy?accounts-window");
 }
 
+static void
+accounts_dialog_button_import_clicked_cb (GtkWidget *button,
+    EmpathyAccountsDialog *dialog)
+{
+  EmpathyAccountsDialogPriv *priv = GET_PRIV (dialog);
+  GtkWidget *import_dialog;
+
+  import_dialog = empathy_import_dialog_new (GTK_WINDOW (priv->window),
+      FALSE);
+  gtk_widget_show (import_dialog);
+}
+
 static void
 accounts_dialog_close_response_cb (GtkDialog *message_dialog,
   gint response_id,
@@ -1651,6 +1661,7 @@ accounts_dialog_build_ui (EmpathyAccountsDialog *dialog)
       "image_type", &priv->image_type,
       "label_name", &priv->label_name,
       "button_add", &priv->button_add,
+      "button_import", &priv->button_import,
       NULL);
   g_free (filename);
 
@@ -1662,6 +1673,7 @@ accounts_dialog_build_ui (EmpathyAccountsDialog *dialog)
       "button_back", "clicked", accounts_dialog_button_back_clicked_cb,
       "button_add", "clicked", accounts_dialog_button_add_clicked_cb,
       "button_help", "clicked", accounts_dialog_button_help_clicked_cb,
+      "button_import", "clicked", accounts_dialog_button_import_clicked_cb,
       NULL);
 
   g_object_unref (gui);
@@ -1760,9 +1772,6 @@ do_constructor (GType type,
 
       dialog_singleton = EMPATHY_ACCOUNTS_DIALOG (retval);
       g_object_add_weak_pointer (retval, (gpointer) &dialog_singleton);
-      /* We add an extra reference that we'll release when the dialog is
-       * destroyed (accounts_dialog_destroy_cb) */
-      g_object_ref (retval);
     }
 
   return retval;
@@ -1826,9 +1835,9 @@ do_constructed (GObject *object)
   empathy_conf_get_bool (empathy_conf_get (),
       EMPATHY_PREFS_IMPORT_ASKED, &import_asked);
 
-
   if (empathy_import_accounts_to_import ())
     {
+      gtk_widget_show (priv->button_import);
 
       if (!import_asked)
         {
@@ -1901,9 +1910,6 @@ empathy_accounts_dialog_show (GtkWindow *parent,
     }
 
   gtk_window_present (GTK_WINDOW (priv->window));
-  /* EmpathyAccountsDialog kepts a ref on itself until the dialog is
-   * destroyed so we can release the ref returned by the constructor now. */
-  g_object_unref (dialog);
 
   return priv->window;
 }
