@@ -126,7 +126,7 @@ chat_window_accel_cb (GtkAccelGroup    *accelgroup,
 {
 	EmpathyChatWindowPriv *priv;
 	gint                  num = -1;
-	gint                  i;
+	guint                 i;
 
 	priv = GET_PRIV (window);
 
@@ -440,6 +440,8 @@ chat_window_update_chat_tab (EmpathyChat *chat)
 	GString               *tooltip;
 	gchar                 *markup;
 	const gchar           *icon_name;
+	GtkWidget             *tab_image;
+	GtkWidget             *menu_image;
 
 	window = chat_window_find_chat (chat);
 	if (!window) {
@@ -457,7 +459,11 @@ chat_window_update_chat_tab (EmpathyChat *chat)
 		name, empathy_account_get_unique_name (account), subject, remote_contact);
 
 	/* Update tab image */
-	if (g_list_find (priv->chats_new_msg, chat)) {
+	if (empathy_chat_get_tp_chat (chat) == NULL) {
+		/* No TpChat, we are disconnected */
+		icon_name = NULL;
+	}
+	else if (g_list_find (priv->chats_new_msg, chat)) {
 		icon_name = EMPATHY_IMAGE_MESSAGE;
 	}
 	else if (g_list_find (priv->chats_composing, chat)) {
@@ -468,10 +474,18 @@ chat_window_update_chat_tab (EmpathyChat *chat)
 	} else {
 		icon_name = EMPATHY_IMAGE_GROUP_MESSAGE;
 	}
-	widget = g_object_get_data (G_OBJECT (chat), "chat-window-tab-image");
-	gtk_image_set_from_icon_name (GTK_IMAGE (widget), icon_name, GTK_ICON_SIZE_MENU);
-	widget = g_object_get_data (G_OBJECT (chat), "chat-window-menu-image");
-	gtk_image_set_from_icon_name (GTK_IMAGE (widget), icon_name, GTK_ICON_SIZE_MENU);
+
+	tab_image = g_object_get_data (G_OBJECT (chat), "chat-window-tab-image");
+	menu_image = g_object_get_data (G_OBJECT (chat), "chat-window-menu-image");
+	if (icon_name != NULL) {
+		gtk_image_set_from_icon_name (GTK_IMAGE (tab_image), icon_name, GTK_ICON_SIZE_MENU);
+		gtk_widget_show (tab_image);
+		gtk_image_set_from_icon_name (GTK_IMAGE (menu_image), icon_name, GTK_ICON_SIZE_MENU);
+		gtk_widget_show (menu_image);
+	} else {
+		gtk_widget_hide (tab_image);
+		gtk_widget_hide (menu_image);
+	}
 
 	/* Update tab tooltip */
 	tooltip = g_string_new (NULL);
@@ -648,7 +662,7 @@ chat_window_favorite_toggled_cb (GtkToggleAction   *toggle_action,
 		chatroom = empathy_chatroom_new_full (account, room, name, FALSE);
 		empathy_chatroom_manager_add (priv->chatroom_manager, chatroom);
 		g_object_unref (chatroom);
-  }
+	}
 
 	empathy_chatroom_set_favorite (chatroom, active);
 }
@@ -818,19 +832,19 @@ chat_window_tabs_left_activate_cb (GtkAction         *action,
 {
 	EmpathyChatWindowPriv *priv;
 	EmpathyChat           *chat;
-	gint                  index;
+	gint                  index_;
 
 	priv = GET_PRIV (window);
 
 	chat = priv->current_chat;
-	index = gtk_notebook_get_current_page (GTK_NOTEBOOK (priv->notebook));
-	if (index <= 0) {
+	index_ = gtk_notebook_get_current_page (GTK_NOTEBOOK (priv->notebook));
+	if (index_ <= 0) {
 		return;
 	}
 
 	gtk_notebook_reorder_child (GTK_NOTEBOOK (priv->notebook),
 				    GTK_WIDGET (chat),
-				    index - 1);
+				    index_ - 1);
 }
 
 static void
@@ -839,16 +853,16 @@ chat_window_tabs_right_activate_cb (GtkAction         *action,
 {
 	EmpathyChatWindowPriv *priv;
 	EmpathyChat           *chat;
-	gint                  index;
+	gint                  index_;
 
 	priv = GET_PRIV (window);
 
 	chat = priv->current_chat;
-	index = gtk_notebook_get_current_page (GTK_NOTEBOOK (priv->notebook));
+	index_ = gtk_notebook_get_current_page (GTK_NOTEBOOK (priv->notebook));
 
 	gtk_notebook_reorder_child (GTK_NOTEBOOK (priv->notebook),
 				    GTK_WIDGET (chat),
-				    index + 1);
+				    index_ + 1);
 }
 
 static void
@@ -1190,6 +1204,9 @@ chat_window_page_added_cb (GtkNotebook      *notebook,
 	g_signal_connect (chat, "new-message",
 			  G_CALLBACK (chat_window_new_message_cb),
 			  window);
+	g_signal_connect (chat, "notify::tp-chat",
+			  G_CALLBACK (chat_window_update_chat_tab),
+			  window);
 
 	/* Set flag so we know to perform some special operations on
 	 * switch page due to the new page being added.
@@ -1234,6 +1251,9 @@ chat_window_page_removed_cb (GtkNotebook      *notebook,
 	g_signal_handlers_disconnect_by_func (chat,
 					      G_CALLBACK (chat_window_new_message_cb),
 					      window);
+	g_signal_handlers_disconnect_by_func (chat,
+					      G_CALLBACK (chat_window_update_chat_tab),
+					      window);
 
 	/* Keep list of chats up to date */
 	priv->chats = g_list_remove (priv->chats, chat);
@@ -1275,7 +1295,7 @@ chat_window_drag_data_received (GtkWidget        *widget,
 				int               y,
 				GtkSelectionData *selection,
 				guint             info,
-				guint             time,
+				guint             time_,
 				EmpathyChatWindow *window)
 {
 	if (info == DND_DRAG_TYPE_CONTACT_ID) {
@@ -1305,7 +1325,7 @@ chat_window_drag_data_received (GtkWidget        *widget,
 
 		if (account == NULL) {
 			g_strfreev (strv);
-			gtk_drag_finish (context, FALSE, FALSE, time);
+			gtk_drag_finish (context, FALSE, FALSE, time_);
 			return;
 		}
 
@@ -1328,7 +1348,7 @@ chat_window_drag_data_received (GtkWidget        *widget,
 		old_window = chat_window_find_chat (chat);
 		if (old_window) {
 			if (old_window == window) {
-				gtk_drag_finish (context, TRUE, FALSE, time);
+				gtk_drag_finish (context, TRUE, FALSE, time_);
 				return;
 			}
 
@@ -1345,7 +1365,7 @@ chat_window_drag_data_received (GtkWidget        *widget,
 		 * weird consequences, and we handle that internally
 		 * anyway with add_chat () and remove_chat ().
 		 */
-		gtk_drag_finish (context, TRUE, FALSE, time);
+		gtk_drag_finish (context, TRUE, FALSE, time_);
 	}
 	else if (info == DND_DRAG_TYPE_TAB) {
 		EmpathyChat        **chat;
@@ -1364,7 +1384,7 @@ chat_window_drag_data_received (GtkWidget        *widget,
 			if (old_window == window) {
 				DEBUG ("DND tab (within same window)");
 				priv->dnd_same_window = TRUE;
-				gtk_drag_finish (context, TRUE, FALSE, time);
+				gtk_drag_finish (context, TRUE, FALSE, time_);
 				return;
 			}
 
@@ -1376,10 +1396,10 @@ chat_window_drag_data_received (GtkWidget        *widget,
 		 * weird consequences, and we handle that internally
 		 * anyway with add_chat () and remove_chat ().
 		 */
-		gtk_drag_finish (context, TRUE, FALSE, time);
+		gtk_drag_finish (context, TRUE, FALSE, time_);
 	} else {
 		DEBUG ("DND from unknown source");
-		gtk_drag_finish (context, FALSE, FALSE, time);
+		gtk_drag_finish (context, FALSE, FALSE, time_);
 	}
 }
 
@@ -1447,7 +1467,7 @@ empathy_chat_window_init (EmpathyChatWindow *window)
 	GClosure              *closure;
 	GtkWidget             *menu;
 	GtkWidget             *submenu;
-	gint                   i;
+	guint                  i;
 	GtkWidget             *chat_vbox;
 	gchar                 *filename;
 	EmpathySmileyManager  *smiley_manager;
