@@ -33,6 +33,7 @@
 
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
+#include <gdk/gdkkeysyms.h>
 
 #define DEBUG_FLAG EMPATHY_DEBUG_FT
 #include <libempathy/empathy-debug.h>
@@ -950,6 +951,21 @@ ft_manager_destroy_cb (GtkWidget *widget,
   g_object_unref (manager);
 }
 
+static gboolean
+ft_manager_key_press_event_cb (GtkWidget *widget,
+                               GdkEventKey *event,
+                               gpointer user_data)
+{
+  if ((event->state & GDK_CONTROL_MASK && event->keyval == GDK_w)
+      || event->keyval == GDK_Escape)
+    {
+      gtk_widget_destroy (widget);
+      return TRUE;
+    }
+
+  return FALSE;
+}
+
 static void
 ft_manager_build_ui (EmpathyFTManager *manager)
 {
@@ -978,6 +994,7 @@ ft_manager_build_ui (EmpathyFTManager *manager)
       "ft_manager_dialog", "response", ft_manager_response_cb,
       "ft_manager_dialog", "delete-event", ft_manager_delete_event_cb,
       "ft_manager_dialog", "configure-event", ft_manager_configure_event_cb,
+      "ft_manager_dialog", "key-press-event", ft_manager_key_press_event_cb,
       NULL);
 
   empathy_builder_unref_and_keep_widget (gui, priv->window);
@@ -1076,7 +1093,6 @@ ft_manager_build_ui (EmpathyFTManager *manager)
 static void
 empathy_ft_manager_finalize (GObject *object)
 {
-  EmpathyFTManager *self = EMPATHY_FT_MANAGER (object);
   EmpathyFTManagerPriv *priv = GET_PRIV (object);
 
   DEBUG ("FT Manager %p", object);
@@ -1084,10 +1100,7 @@ empathy_ft_manager_finalize (GObject *object)
   g_hash_table_destroy (priv->ft_handler_to_row_ref);
 
   if (priv->save_geometry_id != 0)
-    {
-      g_source_remove (priv->save_geometry_id);
-      ft_manager_save_geometry_timeout_cb (self);
-    }
+    g_source_remove (priv->save_geometry_id);
 
   G_OBJECT_CLASS (empathy_ft_manager_parent_class)->finalize (object);
 }
